# Advanced Audio

Surround mixing, bus routing, crossfades, multiband compression,
convolution reverb, and LUFS normalization.

## AudioBus

::: pymotion.audio.mixer.AudioBus

## SurroundChannel

::: pymotion.audio.mixer.SurroundChannel

## ChannelLayout

::: pymotion.audio.mixer.ChannelLayout

## audio_crossfade

::: pymotion.audio.effects.audio_crossfade

## MultibandCompressor

::: pymotion.audio.effects.MultibandCompressor

## ConvolutionReverb

::: pymotion.audio.effects.ConvolutionReverb
